<?php

namespace Assetdocs\Student\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Student\Interfaces\StudentRepositoryInterface;

class StudentController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Student\Interfaces\StudentRepositoryInterface $student
     *
     * @return type
     */
    public function __construct(StudentRepositoryInterface $student)
    {
        $this->middleware('web');
        $this->setupTheme(config('theme.themes.public.theme'), config('theme.themes.public.layout'));

        $this->repository = $student;
        parent::__construct();
    }

    /**
     * Show student's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $students = $this->repository
            ->pushCriteria(new \Assetdocs\Student\Repositories\Criteria\StudentPublicCriteria())
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        return $this->theme->of('student::public.student.index', compact('students'))->render();
    }

    /**
     * Show student.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $student = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('student::public.student.show', compact('student'))->render();
    }
}
