<?php

namespace Assetdocs\Student\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Assetdocs\Student\Models\Student;

class StudentPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the student.
     *
     * @param User $user
     * @param Student $student
     *
     * @return bool
     */
    public function view(User $user, Student $student)
    {
        if ($user->canDo('student.student.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $student->user_id;
    }

    /**
     * Determine if the given user can create a student.
     *
     * @param User $user
     * @param Student $student
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('student.student.create');
    }

    /**
     * Determine if the given user can update the given student.
     *
     * @param User $user
     * @param Student $student
     *
     * @return bool
     */
    public function update(User $user, Student $student)
    {
        if ($user->canDo('student.student.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $student->user_id;
    }

    /**
     * Determine if the given user can delete the given student.
     *
     * @param User $user
     * @param Student $student
     *
     * @return bool
     */
    public function destroy(User $user, Student $student)
    {
        if ($user->canDo('student.student.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $student->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
